var group__double_g_esolve =
[
    [ "dgels", "d7/d3b/group__double_g_esolve_ga225c8efde208eaf246882df48e590eac.html#ga225c8efde208eaf246882df48e590eac", null ],
    [ "dgelsd", "d7/d3b/group__double_g_esolve_ga94bd4a63a6dacf523e25ff617719f752.html#ga94bd4a63a6dacf523e25ff617719f752", null ],
    [ "dgelss", "d7/d3b/group__double_g_esolve_gaa6ed601d0622edcecb90de08d7a218ec.html#gaa6ed601d0622edcecb90de08d7a218ec", null ],
    [ "dgelsx", "d7/d3b/group__double_g_esolve_ga6252143bd7183eb34700395cbe013ff6.html#ga6252143bd7183eb34700395cbe013ff6", null ],
    [ "dgelsy", "d7/d3b/group__double_g_esolve_ga385713b8bcdf85663ff9a45926fac423.html#ga385713b8bcdf85663ff9a45926fac423", null ],
    [ "dgesv", "d7/d3b/group__double_g_esolve_ga5ee879032a8365897c3ba91e3dc8d512.html#ga5ee879032a8365897c3ba91e3dc8d512", null ],
    [ "dgesvx", "d7/d3b/group__double_g_esolve_ga9d90ccf6e340cacd08b7bbbb502ceb21.html#ga9d90ccf6e340cacd08b7bbbb502ceb21", null ],
    [ "dgesvxx", "d7/d3b/group__double_g_esolve_ga3fed1dc691d07f1e81a049016fe0b67b.html#ga3fed1dc691d07f1e81a049016fe0b67b", null ],
    [ "dgetsls", "d7/d3b/group__double_g_esolve_ga24938f890150242a397e2094fc4643db.html#ga24938f890150242a397e2094fc4643db", null ],
    [ "dsgesv", "d7/d3b/group__double_g_esolve_ga05bea3dc0386868e4720f22c969cb9f5.html#ga05bea3dc0386868e4720f22c969cb9f5", null ]
];